var log4js = require('log4js');
var _log = log4js.getLogger('customer.bentheim');

_log.info('load global overrides for Bentheim...');

var mysql = undefined;
try {
	mysql = require("mysql");
} catch (e) {
	_log.error("cannot load mysql; database access not possible", e);
}

// var dbOptions = {
//     host     : "localhost",
//     user     : "smt",
//     password : "smt",
//     database : "bentheim"
// };
var dbOptions = {
    host     : "192.168.0.2",
    user     : "smt",
    password : "smt21?%!",
    database : "kunden"
};

var dbConnected = false;

var dbConnect = function(next) {
    if (!mysql) return;
    var db = mysql.createConnection(dbOptions);

    db.connect(function(err) {
        if (err) { 
            _log.error("error connecting database:", err, "options:", dbOptions); 
            return; 
        }
        dbConnected = true;
        _log.info("connected to database");
        if (next) next(db);
    });
};

var dbSaveShots = function(db, headId, shots, callback) {
    var query = "insert into smt_scores (`headId`, `ts`, `cordX`, `cordY`, `score`, `value`, `isSimulated`) VALUES ";
    for (var n = 0; n < shots.length; n++) {
        var s = shots[n];
        if (!s.valid) continue;
        var isSimulated = (s.sim_data !== undefined ? 1 : 0);
        query += `(${headId}, ${db.escape(new Date(s.ts))}, ${s.x}, ${s.y}, ${s.score}, ${db.escape(s.value)}, ${isSimulated}),`;
        console.log(s);
    }
    query = query.slice(0, -1);
    console.log(query);
    db.query(query, function(err, results, fields) {
        if (err) {
            _log.error('Error while querying the database: ' + err);
            return;
        }
        _log.info('Saved data into database.');
        callback()
    });
};

var dbSaveString = function(string, shots) {
    if (!string.bentheim_shooter) {
        string.bentheim_shooter = 0;
        string.bentheim_end = Date.now();
        var frame = data.frames[string.frame_id];
        if (frame !== undefined) {
            string.bentheim_range = frame.name;
        }
    }
    var countValidShots = 0;
    for (var n = 0; n < shots.length; n++) {
        var s = shots[n];
        if (!s.valid) continue;
        countValidShots++;
    }
    dbConnect(function(db) {
        // save into head table
        var query = "insert into smt_head (`member`, `begin`, `end`, `face`, `range`, `number_shots`, `string`, `stringId`)";
        query += ` values (
            ${string.bentheim_shooter}, 
            ${db.escape(new Date(string.bentheim_begin))}, 
            ${db.escape(new Date(string.bentheim_end))}, 
            '${string.bentheim_face}', 
            '${string.bentheim_range}', 
            ${countValidShots}, 
            '${string.name}',
            ${string._id})`;
        db.query(query, function(err, results, fields) {
            if (err) {
                require('fs').appendFile('db-bentheim.log', new Date().toString() + ' ERROR:' + err + '\r\n', function (err) {if (err) throw err;});
                _log.error('Error while querying the database: ' + err);
                return;
            }
            require('fs').appendFile('db-bentheim.log', new Date().toString() + ' SUCCESS:' + results.insertId + ' ' + string.bentheim_range + '\r\n', function (err) {if (err) throw err;});
            var headId = results.insertId;
            dbSaveShots(db, headId, shots, function() {
                db.end();
            });
        });

    });

};

global.global_customCreateStringDefaults = function(oldString, newString) {
    newString.bentheim_shooter = oldString.bentheim_shooter;
};

global.global_customPreSaveString = function(string) {
    if (string.bentheim_shooter) {
        string.bentheim_end = Date.now();
    }
};

global.bentheim_save_image = function(data, stringId, callback) {
    dbConnect(function(db) {
        // save into head table
        // var query = "insert into smt_pictures (`data`, `stringId`)";
        // query += ` values (BINARY(${db.escape(data)}), ${stringId})`;
        // db.query(query, function(err, results, fields) {
        //     if (err) {
        //         _log.error('Error while querying the database: ' + err);
        //         return;
        //     }
        //     db.end(function() {
        //         _log.info('Saved image into database.');
        //         callback()
        //     });
        // });

    });
};

global.bentheim_load_image = function(id, callback) {
    dbConnect(function(db) {

        var query = "select `data` from smt_pictures where headId=" + id;
        db.query(query, function(err, results, fields) {
            if (err) {
                _log.error('Error while querying the database: ' + err);
                return;
            }
            callback(results[0].data);
            _log.info('Load data from database.');
            db.end();
        });

    });
};

global.global_customPostSaveString = function(string) {
    // save in mysql database...
    var strCopy = JSON.parse(JSON.stringify(string));
    dbSaveString(strCopy, strCopy.shots);
};