/*******************************************************************************
 language.js: multi-language strings translation

 $Author: dmc $
 $Revision: 2564 $
 $Date: 2019-05-18 11:55:01 -0300 (Sat, 18 May 2019) $
 $HeadURL: http://support2.silvermountaintargets.com/svn/smt/smt.common.lib/public/javascripts/language.js $
*******************************************************************************/

var translationStrings = undefined;

function S( id, arg1, arg2, arg3, arg4, arg5 ) {

	if ( translationStrings === undefined ) {
		translationStrings = [];
		$.ajax( {
			dataType: "json",
			url: "./javascripts/translation.json",
			async: true // async = false on main thread gives deprecated warning; and, our code here
			// is perfectly able to deal with an async request
		} )
		.done( function( languageData ) {
			_.forEach( languageData, function( i ) {
				translationStrings[ _.lowerCase( i.key ) ] = i;
			} );
			// if "update" function exists, call it to update the translated strings.
			if ('function' == typeof update) {
				update();
			}
		} )
		.fail( function( ex, type, msg ) {
			alert( "error: " + msg );
		} );
	}

	var stringId = _.lowerCase( id );
	if ( !translationStrings[ stringId ] ) {
		return id;
	}

	//return id;
	var languageCode = g_config.language;
	if ( g_config.language === "AUTO" ) {
		languageCode = getBrowserLanguage();
	}

	var str = translationStrings[ stringId ][ languageCode ];
	if ( !str ) {
		if ( g_config.language !== "none" && translationStrings[ stringId ][ "en" ]) {
			return translationStrings[ stringId ][ "en" ];
		}
		return stringId;
	}

	if ( arg1 !== undefined ) str = replaceAll( "{1}", arg1, str );
	if ( arg2 !== undefined ) str = replaceAll( "{2}", arg2, str );
	if ( arg3 !== undefined ) str = replaceAll( "{3}", arg3, str );
	if ( arg4 !== undefined ) str = replaceAll( "{4}", arg4, str );
	if ( arg5 !== undefined ) str = replaceAll( "{5}", arg5, str );
	return str;
}

var browserLanguage = undefined;
function getBrowserLanguage( ) {
	if ( browserLanguage !== undefined ) {
		return browserLanguage;
	}
	browserLanguage = navigator.language || navigator.browserLanguage || navigator.userLanguage;
	browserLanguage = browserLanguage.split( "-" )[ 0 ];

	if ( browserLanguage === "" || browserLanguage === undefined ) {
		browserLanguage = "en";
	}
	return browserLanguage;
};

function getLanguages() {
	var langs = [];

	_.forEach( translationStrings[ "languages" ], function( value, key ) {
		if ( key !== "key" ) {
			langs.push( { key: key, label: value } );
		}
	} );

	return langs;
}

function escapeRegExp( string ) {
    return string.replace( /([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1" );
}

function replaceAll( find, replace, str ) {
	return str.replace( new RegExp( escapeRegExp( find ), 'g'), replace );
}

